<!--
  ~ Copyright (c) 2007, Red Hat Middleware, LLC. All rights reserved.
  ~
  ~ This copyrighted material is made available to anyone wishing to use, modify,
  ~ copy, or redistribute it subject to the terms and conditions of the GNU
  ~ Lesser General Public License, v. 2.1. This program is distributed in the
  ~ hope that it will be useful, but WITHOUT A WARRANTY; without even the implied
  ~ warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
  ~ Lesser General Public License for more details. You should have received a
  ~ copy of the GNU Lesser General Public License, v.2.1 along with this
  ~ distribution; if not, write to the Free Software Foundation, Inc.,
  ~ 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
  ~
  ~ Red Hat Author(s): Steve Ebersole
  -->

<xsl:stylesheet version='1.0'
        xmlns="http://www.w3.org/TR/xhtml1/transitional"
        xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
		xmlns:exsl="http://exslt.org/common"
		exclude-result-prefixes="exsl">

    <!--
        *NOTE* : html formats do not define the verso coverpage, only the
        recto page.
    -->

    <xsl:import href="basic.xsl"/>

    <!--###################################################-->
    <!--##               The cover page                  ##-->
    <!--###################################################-->
    <xsl:template name="book.titlepage.recto">
        <xsl:choose>
            <xsl:when test="bookinfo/graphic">
                <xsl:apply-templates select="bookinfo/graphic"/>
            </xsl:when>
            <xsl:when test="info/graphic">
                <xsl:apply-templates select="info/graphic"/>
            </xsl:when>
            <xsl:when test="bookinfo/mediaobject">
                <xsl:apply-templates select="bookinfo/mediaobject"/>
            </xsl:when>
            <xsl:when test="info/mediaobject">
                <xsl:apply-templates select="info/mediaobject"/>
            </xsl:when>
        </xsl:choose>

        <xsl:choose>
            <xsl:when test="bookinfo/title">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/title"/>
            </xsl:when>
            <xsl:when test="info/title">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/title"/>
            </xsl:when>
            <xsl:when test="title">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="title"/>
            </xsl:when>
        </xsl:choose>

        <xsl:choose>
            <xsl:when test="bookinfo/subtitle">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/subtitle"/>
            </xsl:when>
            <xsl:when test="info/subtitle">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/subtitle"/>
            </xsl:when>
            <xsl:when test="subtitle">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="subtitle"/>
            </xsl:when>
        </xsl:choose>

        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/releaseinfo"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/releaseinfo"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="releaseinfo"/>

        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/authorgroup"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/authorgroup"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/author"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/author"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/othercredit"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/othercredit"/>

        <xsl:choose>
            <xsl:when test="bookinfo/abstract">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/abstract"/>
            </xsl:when>
            <xsl:when test="info/abstract">
                <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/abstract"/>
            </xsl:when>
        </xsl:choose>

        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/copyright"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/copyright"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/legalnotice"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/legalnotice"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="bookinfo/publisher"/>
        <xsl:apply-templates mode="book.titlepage.recto.auto.mode" select="info/publisher"/>

    </xsl:template>

    <xsl:template match="authorgroup" mode="titlepage.mode">
        <div>
            <xsl:apply-templates select="." mode="class.attribute"/>
            <table border="0" summary="Credits">
                <tr>
                    <th align="left" valign="top" colspan="3">
                        <b>
                            <xsl:call-template name="gentext">
                                <xsl:with-param name="key" select="'Authors'"/>
                            </xsl:call-template>
                        </b>
                    </th>
                </tr>
                <xsl:apply-templates select="author" mode="tablerow.titlepage.mode"/>
                <xsl:apply-templates select="editor" mode="tablerow.titlepage.mode"/>
                <xsl:apply-templates select="othercredit" mode="tablerow.titlepage.mode"/>
            </table>
        </div>
    </xsl:template>

    <xsl:template match="author" mode="tablerow.titlepage.mode">
        <xsl:call-template name="titlecredit">
            <xsl:with-param name="contrib">
                <xsl:call-template name="gentext">
                    <xsl:with-param name="key" select="'Author'"/>
                </xsl:call-template>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:param name="editedby.enabled">0</xsl:param>

    <xsl:template match="editor" mode="tablerow.titlepage.mode">
        <xsl:call-template name="titlecredit">
            <xsl:with-param name="contrib">
                <xsl:call-template name="gentext">
                    <xsl:with-param name="key" select="'Editor'"/>
                </xsl:call-template>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template match="othercredit" mode="tablerow.titlepage.mode">
        <xsl:call-template name="titlecredit">
            <xsl:with-param name="contrib">
                <xsl:call-template name="gentext">
                    <xsl:with-param name="key" select="'translator'"/>
                </xsl:call-template>
            </xsl:with-param>
        </xsl:call-template>
    </xsl:template>

    <xsl:template name="titlecredit">
        <xsl:param name="contrib"/>
        <tr>
            <td>
                <xsl:value-of select="$contrib"/>
            </td>
            <td>
                <xsl:call-template name="person.name">
                    <xsl:with-param name="node" select="."/>
                </xsl:call-template>
            </td>
            <td>
                 <xsl:apply-templates select="email"/>
            </td>
        </tr>
    </xsl:template>

</xsl:stylesheet>